==> liquidctl_1.12.1.orig.tar.gz: liquidctl-1.12.1/docs/README.md <==
Contents
========

General topics
--------------

<!-- sort all but the first item (the project README) -->

- [**The project README: basic setup and use of liquidctl**](../README.md)

Device guides
----------------------

<!-- sort -->

- [ASUS Aura LED (USB-based) controllers](asus-aura-led-guide.md)
- [Aquacomputer D5 Next watercooling pump](aquacomputer-d5next-guide.md)
- [Aquacomputer Farbwerk 360 RGB controller](aquacomputer-farbwerk360-guide.md)
- [Aquacomputer Octo fan controller](aquacomputer-octo-guide.md)
- [Aquacomputer Quadro fan controller](aquacomputer-quadro-guide.md)
- [Asetek 690LC liquid coolers](asetek-690lc-guide.md)
- [Asetek Pro liquid coolers](asetek-pro-guide.md)
- [Corsair Commander Core and Core XT](corsair-commander-core-guide.md)
- [Corsair Commander Pro, Obsidian 1000D and Lighting Node Pro/Core](corsair-commander-guide.md)
- [Corsair HXi and RMi series PSUs](corsair-hxi-rmi-psu-guide.md)
- [Corsair Hydro Platinum and Pro XT all-in-one liquidctl coolers](corsair-platinum-pro-xt-guide.md)
- [DDR4 DIMMs](ddr4-guide.md)
- [Fourth-generation (X3/Z3) NZXT liquid coolers](kraken-x3-z3-guide.md)
- [Gigabyte RGB Fusion 2.0 lighting controllers](gigabyte-rgb-fusion2-guide.md)
- [NVIDIA graphics cards](nvidia-guide.md)
- [NZXT E-series PSUs](nzxt-e-series-psu-guide.md)
- [NZXT HUE 2 and Smart Device V2 controllers](nzxt-hue2-guide.md)
- [NZXT Smart Device (V1) and Grid+ V3](nzxt-smart-device-v1-guide.md)
- [Third-generation (X2,M2) NZXT liquid coolers](kraken-x2-m2-guide.md)

Linux topics
---------------------

<!-- sort -->

- [Making systemd units wait for devices](linux/making-systemd-units-wait-for-devices.md)

Windows topics
-----------------------

<!-- sort -->

- [Running your first command-line-program](windows/running-your-first-command-line-program.md)

Documentation for developers
----------------------------

<!-- sort all but the first item (development process) -->

- [**Development process (including stability guarantees)**](developer/process.md)
- [Capturing USB traffic](developer/capturing-usb-traffic.md)
- [Interacting with devices with Linux hwmon drivers](developer/hwmon)
- [Porting drivers from OpenCorsairLink](developer/porting-drivers-from-opencorsairlink.md)
- [Protocol notes](developer/protocol/)
- [Release checklist](developer/release-checklist.md)
- [Style guide](developer/style-guide.md)
- [Techniques for analyzing USB protocols](developer/techniques-for-analyzing-usb-protocols.md)
- [Virtual Machine Setup for Traffic Capture](developer/creating-vm-for-capture.md)

==> liquidctl_1.13.0.orig.tar.gz: liquidctl-1.13.0/docs/README.md <==
Contents
========

General topics
--------------

<!-- sort all but the first item (the project README) -->

- [**The project README: basic setup and use of liquidctl**](../README.md)

Device guides
----------------------

<!-- sort -->

- [ASUS Aura LED (USB-based) controllers](asus-aura-led-guide.md)
- [Aquacomputer D5 Next watercooling pump](aquacomputer-d5next-guide.md)
- [Aquacomputer Farbwerk 360 RGB controller](aquacomputer-farbwerk360-guide.md)
- [Aquacomputer Octo fan controller](aquacomputer-octo-guide.md)
- [Aquacomputer Quadro fan controller](aquacomputer-quadro-guide.md)
- [Asetek 690LC liquid coolers](asetek-690lc-guide.md)
- [Asetek Pro liquid coolers](asetek-pro-guide.md)
- [Corsair Commander Core and Core XT](corsair-commander-core-guide.md)
- [Corsair Commander Pro, Obsidian 1000D and Lighting Node Pro/Core](corsair-commander-guide.md)
- [Corsair HXi and RMi series PSUs](corsair-hxi-rmi-psu-guide.md)
- [Corsair Hydro Platinum, Pro XT and Elite RGB all-in-one liquidctl coolers](corsair-platinum-pro-xt-guide.md)
- [DDR4 DIMMs](ddr4-guide.md)
- [Fourth-generation (X3/Z3) NZXT liquid coolers](kraken-x3-z3-guide.md)
- [Gigabyte RGB Fusion 2.0 lighting controllers](gigabyte-rgb-fusion2-guide.md)
- [NVIDIA graphics cards](nvidia-guide.md)
- [NZXT E-series PSUs](nzxt-e-series-psu-guide.md)
- [NZXT HUE 2 and Smart Device V2 controllers](nzxt-hue2-guide.md)
- [NZXT Smart Device (V1) and Grid+ V3](nzxt-smart-device-v1-guide.md)
- [Third-generation (X2,M2) NZXT liquid coolers](kraken-x2-m2-guide.md)

Linux topics
---------------------

<!-- sort -->

- [Making systemd units wait for devices](linux/making-systemd-units-wait-for-devices.md)

Windows topics
-----------------------

<!-- sort -->

- [Running your first command-line-program](windows/running-your-first-command-line-program.md)

Documentation for developers
----------------------------

<!-- sort all but the first item (development process) -->

- [**Development process (including stability guarantees)**](developer/process.md)
- [Capturing USB traffic](developer/capturing-usb-traffic.md)
- [Interacting with devices with Linux hwmon drivers](developer/hwmon)
- [Porting drivers from OpenCorsairLink](developer/porting-drivers-from-opencorsairlink.md)
- [Protocol notes](developer/protocol/)
- [Release checklist](developer/release-checklist.md)
- [Style guide](developer/style-guide.md)
- [Techniques for analyzing USB protocols](developer/techniques-for-analyzing-usb-protocols.md)
- [Virtual Machine Setup for Traffic Capture](developer/creating-vm-for-capture.md)
